SQLAlchemy Core — SQLAlchemy 1.2 Documentation

Release: 1.2.0 | Release Date: December 27, 2017

# SQLAlchemy 1.2 Documentation

# SQLAlchemy Core

The breadth of SQLAlchemy’s SQL rendering engine, DBAPI integration, transaction integration, and schema description services are documented here. In contrast to the ORM’s domain-centric mode of usage, the SQL Expression Language provides a schema-centric usage paradigm.

- SQL Expression Language Tutorial
  - Version Check
  - Connecting
  - Define and Create Tables
  - Insert Expressions
  - Executing
  - Executing Multiple Statements
  - Selecting
  - Operators
  - Conjunctions
  - Using Textual SQL
  - Using Aliases
  - Using Joins
  - Everything Else
  - Inserts, Updates and Deletes
  - Further Reference
- SQL Statements and Expressions API
  - Column Elements and Expressions
  - Selectables, Tables, FROM objects
  - Insert, Updates, Deletes
  - SQL and Generic Functions
  - Custom SQL Constructs and Compilation Extension
  - Expression Serializer Extension
- Schema Definition Language
  - Describing Databases with MetaData
  - Reflecting Database Objects
  - Column Insert/Update Defaults
  - Defining Constraints and Indexes
  - Customizing DDL
- Column and Data Types
  - Column and Data Types
  - Custom Types
  - Base Type API
- Engine and Connection Use
  - Engine Configuration
  - Working with Engines and Connections
  - Connection Pooling
  - Core Events
- Core API Basics
  - Events
  - Runtime Inspection API
  - Deprecated Event Interfaces
  - Core Exceptions
  - Core Internals